pitchtools.Vector
=================

.. abjad-lineage:: abjad.tools.pitchtools.Vector.Vector

.. autoclass:: abjad.tools.pitchtools.Vector.Vector

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.Vector.Vector.clear
      ~abjad.tools.pitchtools.Vector.Vector.copy
      ~abjad.tools.pitchtools.Vector.Vector.elements
      ~abjad.tools.pitchtools.Vector.Vector.from_selection
      ~abjad.tools.pitchtools.Vector.Vector.item_class
      ~abjad.tools.pitchtools.Vector.Vector.items
      ~abjad.tools.pitchtools.Vector.Vector.keys
      ~abjad.tools.pitchtools.Vector.Vector.most_common
      ~abjad.tools.pitchtools.Vector.Vector.subtract
      ~abjad.tools.pitchtools.Vector.Vector.update
      ~abjad.tools.pitchtools.Vector.Vector.values
      ~abjad.tools.pitchtools.Vector.Vector.viewitems
      ~abjad.tools.pitchtools.Vector.Vector.viewkeys
      ~abjad.tools.pitchtools.Vector.Vector.viewvalues
      ~abjad.tools.pitchtools.Vector.Vector.__add__
      ~abjad.tools.pitchtools.Vector.Vector.__and__
      ~abjad.tools.pitchtools.Vector.Vector.__contains__
      ~abjad.tools.pitchtools.Vector.Vector.__delitem__
      ~abjad.tools.pitchtools.Vector.Vector.__eq__
      ~abjad.tools.pitchtools.Vector.Vector.__format__
      ~abjad.tools.pitchtools.Vector.Vector.__getitem__
      ~abjad.tools.pitchtools.Vector.Vector.__hash__
      ~abjad.tools.pitchtools.Vector.Vector.__iter__
      ~abjad.tools.pitchtools.Vector.Vector.__len__
      ~abjad.tools.pitchtools.Vector.Vector.__missing__
      ~abjad.tools.pitchtools.Vector.Vector.__ne__
      ~abjad.tools.pitchtools.Vector.Vector.__or__
      ~abjad.tools.pitchtools.Vector.Vector.__repr__
      ~abjad.tools.pitchtools.Vector.Vector.__setitem__
      ~abjad.tools.pitchtools.Vector.Vector.__str__
      ~abjad.tools.pitchtools.Vector.Vector.__sub__

Bases
-----

- :py:class:`datastructuretools.TypedCounter <abjad.tools.datastructuretools.TypedCounter.TypedCounter>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.Vector.Vector.item_class
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.Vector.Vector.clear
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.elements
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.from_selection
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.items
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.keys
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.most_common
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.subtract
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.update
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.values
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.viewitems
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.viewkeys
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.viewvalues
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__delitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__missing__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__setitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Vector.Vector.__sub__
   :noindex:
